@@ -19,11 +19,11 @@ public:
     }
     virtual DDBusExtendedAbstractInterface *initConnect()
     {
-        m_dbusProxy = new org::deepin::dde::SystemInfo1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
+        m_dbusProxy = new __System_SystemInfo1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
         return m_dbusProxy;
     }
 private:
-    org::deepin::dde::SystemInfo1 *m_dbusProxy;
+    __System_SystemInfo1 *m_dbusProxy;
 };
 
 
