@@ -15,15 +15,22 @@ public:
     {
         InitFilterProperies(QStringList({"NTPServer"}));
         InitFilterMethods(QStringList({"SetNTPServer"}));
+        QMap<QString, QString> auth;
+        auth["SetLocalRTC"] = "org.deepin.dde.api.proxy";
+        auth["SetNTP"] = "org.deepin.dde.api.proxy";
+        auth["SetNTPServer"] = "org.deepin.dde.api.proxy";
+        auth["SetTime"] = "org.deepin.dde.api.proxy";
+        auth["SetTimezone"] = "org.deepin.dde.api.proxy";
+        InitCheckAuthorization(auth);
         ServiceStart();
     }
     virtual DDBusExtendedAbstractInterface *initConnect()
     {
-        m_dbusProxy = new org::deepin::dde::Timedate1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
+        m_dbusProxy = new __System_Timedate1(m_dbusName, m_dbusPath, QDBusConnection::systemBus(), this);
         return m_dbusProxy;
     }
 private:
-    org::deepin::dde::Timedate1 *m_dbusProxy;
+    __System_Timedate1 *m_dbusProxy;
 };
 
 
